@@ -2,8 +2,8 @@
 ######################################
 # transformation of correlation
 cor2fisher <- function(r){
-	f1 <- 1/2* base::log( ( 1 + r) / ( 1 - r ) )
-	base::return(f1)
+	f1 <- 1/2* log( ( 1 + r) / ( 1 - r ) )
+	return(f1)
 }
 ########################################		
-  
\ No newline at end of file
+  
