@@ -2,13 +2,13 @@
 ##################################################
 # imputation for grouped data
 mice.impute.grouped <- function (y, ry, x, low=NULL , upp=NULL ,  ...){
-    x <- base::cbind(1, base::as.matrix(x) )
-    newstate <- base::get( "newstate" , pos = base::parent.frame() )  
-    vname <- base::get("vname", pos = base::parent.frame())
-    Y <- base::cbind( low[[vname]] , upp[[vname]] )        
+    x <- cbind(1, as.matrix(x) )
+    newstate <- get( "newstate" , pos = parent.frame() )  
+    vname <- get("vname", pos = parent.frame())
+    Y <- cbind( low[[vname]] , upp[[vname]] )        
     # draw bootstrap sample
-    N <- base::nrow(Y)
-    ind <- base::sample( 1:N , replace=TRUE )
+    N <- nrow(Y)
+    ind <- sample( 1:N , replace=TRUE )
     X1 <- x[ ind , -1]
     Y1 <- Y[ ind , ]
     # fit grouped model to bootstrap sample
@@ -24,6 +24,6 @@ mice.impute.grouped <- function (y, ry, x, low=NULL , upp=NULL ,  ...){
 	samp_quant <- qlow + ( qupp - qlow)* stats::runif(N)
 	# draw imputed value
 	yimp <- stats::qnorm( samp_quant , mean=ypred , sd = sigma )
-    base::return(yimp)    
+    return(yimp)    
 }
-##################################################	
\ No newline at end of file
+##################################################	
