@@ -4,11 +4,11 @@
 
 mice_multilevel_doCall_suppressWarnings <- function( what , args , warnings = TRUE){
 	if (warnings){
-		res <- base::do.call( what = what , args = args)
+		res <- do.call( what = what , args = args)
 	} else {
-		base::suppressWarnings(
-			res <- base::do.call( what = what , args = args)
+		suppressWarnings(
+			res <- do.call( what = what , args = args)
 			)
 	}
-	base::return(res)
-}	
\ No newline at end of file
+	return(res)
+}	
