@@ -2,7 +2,7 @@
 ################################################
 # draw residuals
 mice_multilevel_imputation_draw_residuals <- function(predicted, sigma ){
-	N0 <- base::length(predicted)
+	N0 <- length(predicted)
 	imp <- predicted + stats::rnorm(N0 , mean=0 , sd = sigma)	
-	base::return(imp)
-}	
\ No newline at end of file
+	return(imp)
+}	
