@@ -3,6 +3,6 @@
 # normalize vector to sum of length x
 normalize_vector <- function(x)
 {
-	x  <- base::length(x) * x / base::sum(x)
-	base::return(x)
-}
\ No newline at end of file
+	x  <- length(x) * x / sum(x)
+	return(x)
+}
